// file      : bpkg/version.hxx.in -*- C++ -*-
// copyright : Copyright (c) 2014-2017 Code Synthesis Ltd
// license   : MIT; see accompanying LICENSE file

#ifndef BPKG_VERSION // Note: using the version macro itself.

// Note: using build2 standard versioning scheme. The numeric version format
// is AAABBBCCCDDDE where:
//
// AAA - major version number
// BBB - minor version number
// CCC - bugfix version number
// DDD - alpha / beta (DDD + 500) version number
// E   - final (0) / snapshot (1)
//
// When DDDE is not 0, 1 is subtracted from AAABBBCCC. For example:
//
// Version      AAABBBCCCDDDE
//
// 0.1.0        0000010000000
// 0.1.2        0000010010000
// 1.2.3        0010020030000
// 2.2.0-a.1    0020019990010
// 3.0.0-b.2    0029999995020
// 2.2.0-a.1.z  0020019990011
//
#define BPKG_VERSION       60000000ULL
#define BPKG_VERSION_STR   "0.6.0"
#define BPKG_VERSION_ID    "0.6.0"

#define BPKG_VERSION_MAJOR 0
#define BPKG_VERSION_MINOR 6
#define BPKG_VERSION_PATCH 0

#define BPKG_PRE_RELEASE   false

#define BPKG_SNAPSHOT      0ULL
#define BPKG_SNAPSHOT_ID   ""

#include <libbutl/version.hxx>

#ifdef LIBBUTL_VERSION
#  if !(LIBBUTL_VERSION >= 60000000ULL && LIBBUTL_VERSION < 69990001ULL)
#    error incompatible libbutl version, libbutl [0.6.0 0.7.0-) is required
#  endif
#endif

#include <libbpkg/version.hxx>

#ifdef LIBBPKG_VERSION
#  if !(LIBBPKG_VERSION >= 60000000ULL && LIBBPKG_VERSION < 69990001ULL)
#    error incompatible libbpkg version, libbpkg [0.6.0 0.7.0-) is required
#  endif
#endif

#include <odb/version.hxx>

#ifdef LIBODB_VERSION
#  if !(LIBODB_VERSION == 20049995050ULL)
#    error incompatible libodb version, libodb == 2.5.0-b.5 is required
#  endif
#endif

#include <odb/sqlite/version.hxx>

#ifdef LIBODB_SQLITE_VERSION
#  if !(LIBODB_SQLITE_VERSION == 20049995050ULL)
#    error incompatible libodb-sqlite version, libodb-sqlite == 2.5.0-b.5 is required
#  endif
#endif

// User agent.
//
#if   defined(_WIN32)
# if defined(__MINGW32__)
#  define BPKG_OS "MinGW"
# else
#  define BPKG_OS "Windows"
# endif
#elif defined(__linux)
#  define BPKG_OS "GNU/Linux"
#elif defined(__APPLE__)
#  define BPKG_OS "MacOS"
#elif defined(__CYGWIN__)
#  define BPKG_OS "Cygwin"
#elif defined(__FreeBSD__)
#  define BPKG_OS "FreeBSD"
#elif defined(__OpenBSD__)
#  define BPKG_OS "OpenBSD"
#elif defined(__NetBSD__)
#  define BPKG_OS "NetBSD"
#elif defined(__sun)
#  define BPKG_OS "Solaris"
#elif defined(__hpux)
#  define BPKG_OS "HP-UX"
#elif defined(_AIX)
#  define BPKG_OS "AIX"
#elif defined(__unix)
#  define BPKG_OS "Unix"
#elif defined(__posix)
#  define BPKG_OS "Posix"
#else
#  define BPKG_OS "Other"
#endif

#define BPKG_USER_AGENT                                             \
  "bpkg/" BPKG_VERSION_ID " (" BPKG_OS "; +https://build2.org)"     \
  " libbpkg/" LIBBPKG_VERSION_ID                                    \
  " libbutl/" LIBBUTL_VERSION_ID

#endif // BPKG_VERSION
